@@ -16,7 +16,7 @@ use Net::IMP::Debug qw(debug $DEBUG $DEBUG_RX);
 use Net::Inspect::Debug qw(%TRACE);
 use Carp 'croak';
 
-our $VERSION = '0.9434';
+our $VERSION = '0.944';
 
 # try IPv6 using IO::Socket::IP or IO::Socket::INET6
 # fallback to IPv4 only
@@ -36,7 +36,7 @@ sub new {
     my ($class,@args) = @_;
     my $self = fields::new($class);
     $self->{impns} = [qw(App::HTTP_Proxy_IMP::IMP Net::IMP::HTTP Net::IMP)];
-    %$self = %{ shift(@args) } if @args && ref($args[0]);
+    %$self = ( %$self, %{ shift(@args) }) if @args && ref($args[0]);
     $self->getoptions(@args) if @args;
     return $self;
 }
